/*
 * SPDX-FileCopyrightText: 2018-2020 Bruce Cowan <bruce@bcowan.me.uk>
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "config.h"

#include "glob-app-window.h"

#include <gtk/gtk.h>

static GSettings *settings;
static GtkWidget *window;

static void
glob_about (G_GNUC_UNUSED GSimpleAction *action,
            G_GNUC_UNUSED GVariant      *parameter,
                          gpointer       user_data)
{
    GtkWindow *window = gtk_application_get_active_window (GTK_APPLICATION (user_data));

    const gchar *authors[] =
    {
        "Bruce Cowan <bruce@bcowan.me.uk>",
        NULL
    };

    gtk_show_about_dialog (window,
                           "authors", authors,
                           "license-type", GTK_LICENSE_GPL_3_0,
                           "program-name", "Wordsearch",
                           "copyright", "Copyright 2012–2020 Bruce Cowan",
                           "version", PACKAGE_VERSION,
                           "logo-icon-name", "system-search",
                           NULL);
}

static const GActionEntry glob_app_entries[] =
{
    { .name = "about", .activate = glob_about }
};

static void
on_startup (              GApplication *app,
            G_GNUC_UNUSED gpointer      user_data)
{
    g_action_map_add_action_entries (G_ACTION_MAP (app),
                                     glob_app_entries,
                                     G_N_ELEMENTS (glob_app_entries),
                                     app);

    settings = g_settings_new ("uk.me.bcowan.Wordsearch");

    g_autoptr(GAction) mode_action = g_settings_create_action (settings, "mode");
    g_action_map_add_action (G_ACTION_MAP (app), mode_action);
}

static void
on_activate (              GApplication *app,
             G_GNUC_UNUSED gpointer      user_data)
{
    if (!window)
        window = glob_app_window_new (GTK_APPLICATION (app));

    gtk_window_present (GTK_WINDOW (window));
}

int
main (int    argc,
      char **argv)
{
    GtkApplication *app = gtk_application_new ("uk.me.bcowan.Wordsearch",
                                               G_APPLICATION_FLAGS_NONE);

    g_signal_connect (app, "activate",
                      G_CALLBACK (on_activate), NULL);
    g_signal_connect (app, "startup",
                      G_CALLBACK (on_startup), NULL);

    return g_application_run (G_APPLICATION (app), argc, argv);
}
